@@ -1,7 +1,7 @@
 from django.db import models
 from edc_constants.choices import YES_NO_NA
 from edc_constants.constants import NOT_APPLICABLE
-from edc_model.models import date_not_future
+from edc_model.validators import date_not_future
 from edc_protocol.validators import date_not_before_study_start
 
 from ..choices import SPUTUM_GENEXPERT
