@@ -1,7 +1,7 @@
 from django.contrib import admin
 from django_audit_fields import audit_fieldset_tuple
 
-from edc_microbiology.fieldsets import get_urine_culture_fieldset
+from ..fieldsets import get_urine_culture_fieldset
 
 
 class UrineCultureModelAdminMixin:
@@ -13,6 +13,6 @@ class UrineCultureModelAdminMixin:
 
     radio_fields = {
         "urine_culture_performed": admin.VERTICAL,
-        "urine_culture_results": admin.VERTICAL,
+        "urine_culture_result": admin.VERTICAL,
         "urine_culture_organism": admin.VERTICAL,
     }
